VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "DriveInfo"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Option Explicit

'==================================================================
'
' Disk Drive Information
'
' 29 September 2001
'
' You're free in using this software, as long as the
' orignal copyright/author information remains intact.
' In other words, respecting the person(s) who made it
' possible for you to view/learn something of this software.
'
' Copyright  2001 - Diederik van der Boor
' http://www.codingdomain.com
'
'==================================================================


'------------------------------------------------------------------
' Local Variables

Private CurDrive As String


'------------------------------------------------------------------
' Public API constants

Public Enum DriveType
  DRIVE_REMOVABLE = 2
  DRIVE_FIXED = 3
  DRIVE_REMOTE = 4
  DRIVE_CDROM = 5
  DRIVE_RAMDISK = 6
End Enum


'------------------------------------------------------------------
' API Declarations

Private Declare Function GetDriveType Lib "kernel32" Alias "GetDriveTypeA" (ByVal nDrive As String) As Long
Private Declare Function GetVolumeInformation Lib "kernel32" Alias "GetVolumeInformationA" (ByVal lpRootPathName As String, ByVal lpVolumeNameBuffer As String, ByVal nVolumeNameSize As Long, lpVolumeSerialNumber As Long, lpMaximumComponentLength As Long, lpFileSystemFlags As Long, ByVal lpFileSystemNameBuffer As String, ByVal nFileSystemNameSize As Long) As Long
Private Declare Function SetVolumeLabel Lib "kernel32" Alias "SetVolumeLabelA" (ByVal lpRootPathName As String, ByVal lpVolumeName As String) As Long



'------------------------------------------------------------------
' Current Drive the information is requested from

Public Property Get Drive() As String
  Drive = CurDrive
End Property

Public Property Let Drive(NewValue As String)
  CurDrive = NewValue
End Property


'------------------------------------------------------------------
' Drive available and exists?

Public Function Exists() As Boolean
  Exists = (GetDriveType(CurDrive) >= 2)
End Function

Public Function Available() As Boolean
  On Error Resume Next
  Available = (Me.FileSystem <> "")
  Err.Clear
End Function


'------------------------------------------------------------------
' Get the information about the drive

Public Property Get DriveType() As DriveType
  DriveType = GetDriveType(CurDrive)
  If DriveType < 2 Then
    DriveType = 0
    Error 68
  End If
End Property

Public Property Get FileSystem() As String
  FileSystem = Space(255)
  If GetVolumeInformation(CurDrive, vbNullString, 0, 0, 0, 0, FileSystem, Len(FileSystem)) <> 0 Then
    FileSystem = Left(FileSystem, InStr(1, FileSystem, vbNullChar) - 1)
  Else
    FileSystem = ""
    Err.Raise 12345, "Drives", "Could not get drive info!"
  End If
End Property

Public Property Get VolumeName() As String
  VolumeName = Space(255)
  If GetVolumeInformation(CurDrive, VolumeName, Len(VolumeName), 0, 0, 0, vbNullString, 0) <> 0 Then
    VolumeName = Left(VolumeName, InStr(1, VolumeName, vbNullChar) - 1)
  Else
    VolumeName = ""
    Err.Raise 12345, "Drives", "Could not get drive info!"
  End If
End Property

Public Property Let VolumeName(NewValue As String)
  If SetVolumeLabel(CurDrive, NewValue) = 0 Then Err.Raise 12345, "Drives", "Could not set volume name!"
End Property

Public Property Get Serial() As String
  Dim SerNo As Long
  If GetVolumeInformation(CurDrive, vbNullString, 0, SerNo, 0, 0, vbNullString, 0) <> 0 Then
    Serial = Hex(SerNo)
    Serial = Left(Serial, 4) & "-" & Right(Serial, 4)
  Else
    Err.Raise 12345, "Drives", "Could not get drive info!"
  End If
End Property
